is.tridiagonal: Checking a matrix is tridiagonal

Description Usage Arguments Value Examples

View source: R/istridiagonal.R

Description

A function for checking whether a matrix is tridiagonal. The check is used before attempting to apply the BG method for computing the permanent, since the method is only applicable to tridiagonal matrices.

Usage

1

Arguments

A

A matrix.

Value

A logical variable. TRUE if the A is tridiagonal, FALSE otherwise.

Examples

1
2
3
4

Example output

Attaching package: ‘expperm’

The following object is masked from ‘package:base’:

    sink

[1] FALSE
[1] TRUE

expperm documentation built on May 29, 2019, 1:02 a.m.